#
# spec file for package libquo
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2014-2016 Christoph Junghans <junghans@votca.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libquo
Version:        1.4
%global sover   8
Release:        1.6
Summary:        A library for run-time tuning of process binding policies
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://lanl.github.io/libquo/
Source:         https://lanl.github.io/libquo/dists/%{name}-%{version}.tar.gz
BuildRequires:  hwloc
BuildRequires:  numactl
BuildRequires:  openmpi-macros-devel
BuildRequires:  pkgconfig

%description
QUO is an API tailored for MPI/MPI+X codes that may benefit from
evolving process binding policies during their execution. QUO allows
for arbitrary process binding policies to be enacted and reverted
during the execution as different computational phases are entered
and exited, respectively.

%package -n libquo%{sover}
Summary:        A library for run-time tuning of process binding policies
Group:          System/Libraries

%description -n libquo%{sover}
QUO is an API tailored for MPI/MPI+X codes that may benefit from
evolving process binding policies during their execution. QUO allows
for arbitrary process binding policies to be enacted and reverted
during the execution as different computational phases are entered
and exited, respectively.

%package devel
Summary:        Development headers and libraries for libquo
Group:          Development/Libraries/C and C++
Requires:       libquo%{sover} = %{version}-%{release}

%description devel
QUO is an API tailored for MPI/MPI+X codes that may benefit from
evolving process binding policies during their execution. QUO allows
for arbitrary process binding policies to be enacted and reverted
during the execution as different computational phases are entered
and exited, respectively.

This package contains development headers and libraries for libquo.

%prep
%setup -q

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%setup_openmpi

DATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
%configure --disable-silent-rules --enable-shared CC=mpicc USER="Opensuse-builder" HOSTNAME="Opensuse" DATE="$DATE"
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libquo%{sover} -p /sbin/ldconfig
%postun -n libquo%{sover} -p /sbin/ldconfig

%files -n libquo%{sover}
%{_libdir}/libquo.so.%{sover}*

%files devel
%{_bindir}/quo-info
%{_includedir}/*.h
%{_libdir}/libquo.so
%{_libdir}/libquo.a
%{_libdir}/pkgconfig/libquo.pc

%changelog
* Mon Mar 18 2024 Christoph Junghans <junghans@votca.org>
- update to 1.4:
  * Update to hwloc-2.10.0
  * Change QUO_stringify_cbind's output format to list
  * Remove unused typedef
  * Fix comment in quo.h
* Fri Oct  1 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Use openmpi macros to always build with the default openmpi version.
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3.1:
  * see https://github.com/lanl/libquo/compare/v1.3...v1.3.1
- remove 29.patch (upstream)
* Fri Nov  1 2019 Christoph Junghans <junghans@votca.org>
- generify used mpi implementation
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
- Run spec-cleaner
* Thu Oct 26 2017 junghans@votca.org
- added 29.patch to fix return value for comp_dgemv
* Wed Oct 25 2017 junghans@votca.org
- version bump to v1.3
  * Drop 27.patch, merged upstream
  * Changes: https://github.com/lanl/libquo/compare/v1.2.9...v1.3
  - add c++ api
* Wed Oct 25 2017 junghans@votca.org
- adapt to new openlmi package - source mpivars.h during build
* Fri Jan 27 2017 junghans@votca.org
- added patch from upsteam - 27.patch to make build
  reproducible
* Mon Jan 16 2017 junghans@votca.org
- Updated homepage and source url
* Sun Jan  1 2017 jengelh@inai.de
- Trim filler words from description
* Wed Aug 24 2016 junghans@votca.org
- version bumped to 1.2.9, details:
  https://github.com/losalamos/libquo/commits/master
- added quo-info to devel package
- bumped so version to 4
* Sat Oct 10 2015 junghans@votca.org
- version bumped to 1.2.4, details:
  https://github.com/losalamos/libquo/commits/master
- added pkg-config file to devel package
* Thu Nov 20 2014 junghans@votca.org
- initial commit
